/* basic.c
 *
 * Copyright 2018 Bruce Cowan <bruce@bcowan.me.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include <glib.h>

#include "array.h"

#define LENGTH 100

static Array *
create_array (size_t length)
{
    Array *array = array_new (g_free);

    for (size_t i = 0; i < length; i++)
    {
        gchar *str = g_strdup_printf ("String #%zu", i);
        array_add (array, str);
    }

    return array;
}

static void
test_get (void)
{
    Array *array = create_array (LENGTH);

    for (size_t i = 0; i < LENGTH; i++)
    {
        const gchar *element = (const gchar *) array_get (array, i);
        g_autofree gchar *compare = g_strdup_printf ("String #%zu", i);
        g_assert_cmpstr (element, ==, compare);
    }

    array_unref (array);
}

int
main (int    argc,
      char **argv)
{
    g_test_init (&argc, &argv, NULL);

    g_test_add_func ("/array/get", test_get);

    return g_test_run ();
}
